# Contributor Covenant Code of Conduct

## Our Pledge

Here at Spotipy, we would like to promote an environment which is open and 
welcoming to all. As contributors and maintainers we want to guarantee an 
experience which is free of harassment for everyone. By everyone, we mean everyone, 
regardless of: age, body size, disability, ethnicity, sex characteristics, gender 
identity and expression, level of experience, education, socio-economic status, 
nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

Here are some examples of conduct which we believe is conducive to and contributes 
to a positive environment:

* Use of welcoming and inclusive language
* Giving due respect to differing viewpoints and experiences
* Being accepting of constructive criticism
* Being focused on what is best for the community
* Displaying empathy towards other members of the community

Here are some examples of conduct which we believe are unacceptable:

* Using sexualized language/imagery or giving other community members unwelcome 
  sexual attention
* Making insulting/derogatory comments to other community members, or making 
  personal/political attacks against other community members
* Trolling
* Harassing other members publicly or privately
* Doxxing other community members (leaking private information without first getting consent)
* Any other behavior which would be considered inappropriate in a professional setting

## Our Responsibilities

As project maintainers, we are responsible for clearly laying out standards for proper 
conduct. We are also responsible for taking the appropriate actions if and when a 
community member does not act with proper conduct. An example of appropriate action 
is removing/editing/rejecting comments/commits/code/wiki edits/issues or other 
contributions made by such an offender. If a community members continues to act in a 
way contrary to the Code of Conduct, it is our responsibility to ban them (temporarily 
or permanently). 

## Scope

Community members are expected to adhere to the Code of Conduct within all project spaces, 
as well as in all public spaces when representing the Spotipy community.

## Enforcement
Please report instances of abusive, harassing, or otherwise unacceptable behavior to us. 
All complaints will be investigated and reviewed by the project team and will result in 
an appropriate response. The project team is obligated to maintain confidentiality with 
regard to the reporter of an incident.

Project maintainers who do not follow or enforce the Code of Conduct in good faith may 
face temporary or permanent repercussions as determined by other members of the project’s 
leadership.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 1.4, available at 
https://www.contributor-covenant.org/version/1/4/code-of-conduct.html. For answers to 
common questions about this code of conduct, see https://www.contributor-covenant.org/faq
